==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/df/d36/classServerNetworkAdminSocketHandler.js <==
var classServerNetworkAdminSocketHandler =
[
    [ "ServerNetworkAdminSocketHandler", "df/d36/classServerNetworkAdminSocketHandler.html#af67a4d12b8a6cd303085184eb153a23a", null ],
    [ "~ServerNetworkAdminSocketHandler", "df/d36/classServerNetworkAdminSocketHandler.html#af31662b406f32e23c36e41936de4ddd1", null ],
    [ "AcceptConnection", "df/d36/classServerNetworkAdminSocketHandler.html#a856d258e14ef9a26f8ac3940bb753177", null ],
    [ "AllowConnection", "df/d36/classServerNetworkAdminSocketHandler.html#a8cc48bd47c947e4515f04152aa34f95c", null ],
    [ "GetName", "df/d36/classServerNetworkAdminSocketHandler.html#ab971fd1062066c8d8a84edb0a81efcf1", null ],
    [ "Receive_ADMIN_CHAT", "df/d36/classServerNetworkAdminSocketHandler.html#a2be78db5fb429dc7995a4d759cc4a9ed", null ],
    [ "Receive_ADMIN_GAMESCRIPT", "df/d36/classServerNetworkAdminSocketHandler.html#a61acd4bf380669cdfcc452b5f5f4b745", null ],
    [ "Receive_ADMIN_JOIN", "df/d36/classServerNetworkAdminSocketHandler.html#abb648ee7c3fe41c8cf38bcf5942e433d", null ],
    [ "Receive_ADMIN_PING", "df/d36/classServerNetworkAdminSocketHandler.html#a531031b7be28f0ee717aa6c8b17475d7", null ],
    [ "Receive_ADMIN_POLL", "df/d36/classServerNetworkAdminSocketHandler.html#adeb67d367420f1e2f34d3649c46a2976", null ],
    [ "Receive_ADMIN_QUIT", "df/d36/classServerNetworkAdminSocketHandler.html#a17950ec0e3acc44da847597cb4577272", null ],
    [ "Receive_ADMIN_RCON", "df/d36/classServerNetworkAdminSocketHandler.html#a1dc2883bb38ce71f252ba02e731d66b7", null ],
    [ "Receive_ADMIN_UPDATE_FREQUENCY", "df/d36/classServerNetworkAdminSocketHandler.html#a00473f1db00c5070f22f6b9c4d0abd00", null ],
    [ "Send", "df/d36/classServerNetworkAdminSocketHandler.html#a018d51652379599f18a255f66fe80804", null ],
    [ "SendChat", "df/d36/classServerNetworkAdminSocketHandler.html#a0b1c4a7e94e323dc13586cd8ba9e0d80", null ],
    [ "SendClientError", "df/d36/classServerNetworkAdminSocketHandler.html#a41b8b9a781d9114a4b7626abfc94d955", null ],
    [ "SendClientInfo", "df/d36/classServerNetworkAdminSocketHandler.html#a262a87f57515098bfc194eba28fc8b9a", null ],
    [ "SendClientJoin", "df/d36/classServerNetworkAdminSocketHandler.html#ad28a7a660a74f7d4f9acbfd56607e625", null ],
    [ "SendClientQuit", "df/d36/classServerNetworkAdminSocketHandler.html#ac50d21e53c9db3a7eb00423245aa5cac", null ],
    [ "SendClientUpdate", "df/d36/classServerNetworkAdminSocketHandler.html#a19dee6a98e81c8da3de956e0a863e5be", null ],
    [ "SendCmdLogging", "df/d36/classServerNetworkAdminSocketHandler.html#acc35a998cd8c4c61aae7674c8c299c7c", null ],
    [ "SendCmdNames", "df/d36/classServerNetworkAdminSocketHandler.html#a490f16c2a2054b27f81818a5e264d360", null ],
    [ "SendCompanyEconomy", "df/d36/classServerNetworkAdminSocketHandler.html#aa7477138799271d60a69b6a4479a0aa7", null ],
    [ "SendCompanyInfo", "df/d36/classServerNetworkAdminSocketHandler.html#a7ad792e8e1064bea99060875b4b0ef27", null ],
    [ "SendCompanyNew", "df/d36/classServerNetworkAdminSocketHandler.html#ac71124f25ca2040cd21376727ab2d2a2", null ],
    [ "SendCompanyRemove", "df/d36/classServerNetworkAdminSocketHandler.html#a37bb5af4eb8c147a247de3304163b3db", null ],
    [ "SendCompanyStats", "df/d36/classServerNetworkAdminSocketHandler.html#a71483829ba35e09d6aeaf6817de49a0b", null ],
    [ "SendCompanyUpdate", "df/d36/classServerNetworkAdminSocketHandler.html#ab401f940b7c19a9bb36b7bd7b0a88efc", null ],
    [ "SendConsole", "df/d36/classServerNetworkAdminSocketHandler.html#a35359818d45ed364c6550b4b4027f6e9", null ],
    [ "SendDate", "df/d36/classServerNetworkAdminSocketHandler.html#a0d58f656401e45d5f532ae4defa1e192", null ],
    [ "SendError", "df/d36/classServerNetworkAdminSocketHandler.html#af81f6ee9b13c7c2aadcd8954c2a982e1", null ],
    [ "SendGameScript", "df/d36/classServerNetworkAdminSocketHandler.html#aeee10ae2db018064358dd02c91ffda5d", null ],
    [ "SendNewGame", "df/d36/classServerNetworkAdminSocketHandler.html#a34fa3cd2ecf007dbcb6589322710964b", null ],
    [ "SendPong", "df/d36/classServerNetworkAdminSocketHandler.html#af5c08dc2819e6b12bdbec74ccff25214", null ],
    [ "SendProtocol", "df/d36/classServerNetworkAdminSocketHandler.html#aca9300e062cdb1ddbd8547f8200f7803", null ],
    [ "SendRcon", "df/d36/classServerNetworkAdminSocketHandler.html#a591d3e21a6663982090046b30b1d8609", null ],
    [ "SendRconEnd", "df/d36/classServerNetworkAdminSocketHandler.html#a99f61b61cd44c6be12e895c1f31b5ebf", null ],
    [ "SendShutdown", "df/d36/classServerNetworkAdminSocketHandler.html#a70454423e026d8967bdcf2b8e798bb19", null ],
    [ "SendWelcome", "df/d36/classServerNetworkAdminSocketHandler.html#a75e0fc65c2e46672e4fd049b976789bd", null ],
    [ "WelcomeAll", "df/d36/classServerNetworkAdminSocketHandler.html#a7e35fddc1a540f171b7b230061a8555c", null ],
    [ "address", "df/d36/classServerNetworkAdminSocketHandler.html#abd7e961f0c92648b0dae7311beb37219", null ],
    [ "realtime_connect", "df/d36/classServerNetworkAdminSocketHandler.html#a1dc183e2f8dff844d1694e758a4a11f2", null ],
    [ "update_frequency", "df/d36/classServerNetworkAdminSocketHandler.html#a1d71a657bf042697ee1134c7192bb06e", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/df/d36/classServerNetworkAdminSocketHandler.js <==
var classServerNetworkAdminSocketHandler =
[
    [ "ServerNetworkAdminSocketHandlerFilter", "dc/dba/structServerNetworkAdminSocketHandler_1_1ServerNetworkAdminSocketHandlerFilter.html", "dc/dba/structServerNetworkAdminSocketHandler_1_1ServerNetworkAdminSocketHandlerFilter" ],
    [ "ServerNetworkAdminSocketHandler", "df/d36/classServerNetworkAdminSocketHandler.html#af67a4d12b8a6cd303085184eb153a23a", null ],
    [ "~ServerNetworkAdminSocketHandler", "df/d36/classServerNetworkAdminSocketHandler.html#af31662b406f32e23c36e41936de4ddd1", null ],
    [ "AcceptConnection", "df/d36/classServerNetworkAdminSocketHandler.html#a856d258e14ef9a26f8ac3940bb753177", null ],
    [ "AllowConnection", "df/d36/classServerNetworkAdminSocketHandler.html#a8cc48bd47c947e4515f04152aa34f95c", null ],
    [ "GetName", "df/d36/classServerNetworkAdminSocketHandler.html#ab971fd1062066c8d8a84edb0a81efcf1", null ],
    [ "IterateActive", "df/d36/classServerNetworkAdminSocketHandler.html#a3fe7a77a5cf2cda47b4dfa49ba5edc23", null ],
    [ "Receive_ADMIN_CHAT", "df/d36/classServerNetworkAdminSocketHandler.html#a480d281e75cbaaf97cd71507db4b6379", null ],
    [ "Receive_ADMIN_GAMESCRIPT", "df/d36/classServerNetworkAdminSocketHandler.html#a4b693490fe44c31c7acf7b571eba4725", null ],
    [ "Receive_ADMIN_JOIN", "df/d36/classServerNetworkAdminSocketHandler.html#acfac4e897e86935c69a0c27c2908ac70", null ],
    [ "Receive_ADMIN_PING", "df/d36/classServerNetworkAdminSocketHandler.html#a746aebd63d53bed48de0071b8714d442", null ],
    [ "Receive_ADMIN_POLL", "df/d36/classServerNetworkAdminSocketHandler.html#a0ac1f1258af1c15086ee007ed0d18b0d", null ],
    [ "Receive_ADMIN_QUIT", "df/d36/classServerNetworkAdminSocketHandler.html#a147441ec7934253222afadf30164f332", null ],
    [ "Receive_ADMIN_RCON", "df/d36/classServerNetworkAdminSocketHandler.html#acc6e6080888749a2d8f5afa90babcfa1", null ],
    [ "Receive_ADMIN_UPDATE_FREQUENCY", "df/d36/classServerNetworkAdminSocketHandler.html#a9d0bcaeca0cf297cb1f883f8286513ee", null ],
    [ "Send", "df/d36/classServerNetworkAdminSocketHandler.html#a018d51652379599f18a255f66fe80804", null ],
    [ "SendChat", "df/d36/classServerNetworkAdminSocketHandler.html#a0b1c4a7e94e323dc13586cd8ba9e0d80", null ],
    [ "SendClientError", "df/d36/classServerNetworkAdminSocketHandler.html#a41b8b9a781d9114a4b7626abfc94d955", null ],
    [ "SendClientInfo", "df/d36/classServerNetworkAdminSocketHandler.html#a262a87f57515098bfc194eba28fc8b9a", null ],
    [ "SendClientJoin", "df/d36/classServerNetworkAdminSocketHandler.html#ad28a7a660a74f7d4f9acbfd56607e625", null ],
    [ "SendClientQuit", "df/d36/classServerNetworkAdminSocketHandler.html#ac50d21e53c9db3a7eb00423245aa5cac", null ],
    [ "SendClientUpdate", "df/d36/classServerNetworkAdminSocketHandler.html#a19dee6a98e81c8da3de956e0a863e5be", null ],
    [ "SendCmdLogging", "df/d36/classServerNetworkAdminSocketHandler.html#acc35a998cd8c4c61aae7674c8c299c7c", null ],
    [ "SendCmdNames", "df/d36/classServerNetworkAdminSocketHandler.html#a490f16c2a2054b27f81818a5e264d360", null ],
    [ "SendCompanyEconomy", "df/d36/classServerNetworkAdminSocketHandler.html#aa7477138799271d60a69b6a4479a0aa7", null ],
    [ "SendCompanyInfo", "df/d36/classServerNetworkAdminSocketHandler.html#a7ad792e8e1064bea99060875b4b0ef27", null ],
    [ "SendCompanyNew", "df/d36/classServerNetworkAdminSocketHandler.html#ac71124f25ca2040cd21376727ab2d2a2", null ],
    [ "SendCompanyRemove", "df/d36/classServerNetworkAdminSocketHandler.html#a37bb5af4eb8c147a247de3304163b3db", null ],
    [ "SendCompanyStats", "df/d36/classServerNetworkAdminSocketHandler.html#a71483829ba35e09d6aeaf6817de49a0b", null ],
    [ "SendCompanyUpdate", "df/d36/classServerNetworkAdminSocketHandler.html#ab401f940b7c19a9bb36b7bd7b0a88efc", null ],
    [ "SendConsole", "df/d36/classServerNetworkAdminSocketHandler.html#a35359818d45ed364c6550b4b4027f6e9", null ],
    [ "SendDate", "df/d36/classServerNetworkAdminSocketHandler.html#a0d58f656401e45d5f532ae4defa1e192", null ],
    [ "SendError", "df/d36/classServerNetworkAdminSocketHandler.html#af81f6ee9b13c7c2aadcd8954c2a982e1", null ],
    [ "SendGameScript", "df/d36/classServerNetworkAdminSocketHandler.html#aeee10ae2db018064358dd02c91ffda5d", null ],
    [ "SendNewGame", "df/d36/classServerNetworkAdminSocketHandler.html#a34fa3cd2ecf007dbcb6589322710964b", null ],
    [ "SendPong", "df/d36/classServerNetworkAdminSocketHandler.html#af5c08dc2819e6b12bdbec74ccff25214", null ],
    [ "SendProtocol", "df/d36/classServerNetworkAdminSocketHandler.html#aca9300e062cdb1ddbd8547f8200f7803", null ],
    [ "SendRcon", "df/d36/classServerNetworkAdminSocketHandler.html#a591d3e21a6663982090046b30b1d8609", null ],
    [ "SendRconEnd", "df/d36/classServerNetworkAdminSocketHandler.html#a99f61b61cd44c6be12e895c1f31b5ebf", null ],
    [ "SendShutdown", "df/d36/classServerNetworkAdminSocketHandler.html#a70454423e026d8967bdcf2b8e798bb19", null ],
    [ "SendWelcome", "df/d36/classServerNetworkAdminSocketHandler.html#a75e0fc65c2e46672e4fd049b976789bd", null ],
    [ "WelcomeAll", "df/d36/classServerNetworkAdminSocketHandler.html#a7e35fddc1a540f171b7b230061a8555c", null ],
    [ "address", "df/d36/classServerNetworkAdminSocketHandler.html#abd7e961f0c92648b0dae7311beb37219", null ],
    [ "realtime_connect", "df/d36/classServerNetworkAdminSocketHandler.html#a1dc183e2f8dff844d1694e758a4a11f2", null ],
    [ "update_frequency", "df/d36/classServerNetworkAdminSocketHandler.html#a1d71a657bf042697ee1134c7192bb06e", null ]
];
